<?php
/**
 * Class model
 *
 * @package wp-checkout-maximizer
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPChm_Model' )) {

  /**
   * Class for manage post setting
   */
  class IPChm_Model
  {
    /**
     * Save setting
     *
     * @param  int $postId
     * @return void
     */
    public function saveSetting( $postId )
    {
      $postId   = absint( $postId );
      $data     = $this->_getSettingData();
      $setting  = new IPChm_Setting( $postId, '__ipchm-setting' );
      $result   = $setting->setSettings( $data );
      return $result;
    }

    /**
     * Get setting data
     *
     * @return array
     */
    protected function _getSettingData()
    {
      $setting = array();
      $data    = array_merge( $_POST, $_GET );

      //
      //General
      //
      if ( isset( $data['active'] )) {
          $setting['active'] = apply_filters( 'pre_term_name', $data['active'] );
      }

      //
      //
      // Top Content
      //
      if ( isset( $data['top_title'] )) {
        $setting['top_title'] = apply_filters( 'single_post_title', $data['top_title'] );
      }
      if ( isset( $data['top_description'] )) {
        $setting['top_description'] = apply_filters( 'single_post_title', $data['top_description'] );
      }
      if ( isset( $data['top_agreement'] )) {
        $setting['top_agreement'] = apply_filters( 'single_post_title', $data['top_agreement'] );
      }

      //
      //
      // Bottom Content
      //
      if ( isset( $data['bottom_term'] )) {
        $setting['bottom_term'] = apply_filters( 'single_post_title', $data['bottom_term'] );
      }
      if ( isset( $data['bottom_text'] )) {
        $setting['bottom_text'] = apply_filters( 'single_post_title', $data['bottom_text'] );
      }
      if ( isset( $data['bottom_logo'] )) {
        $setting['bottom_logo'] = absint( $data['bottom_logo'] );
      }

      //
      //
      // Design
      //
      if ( isset( $data['background_color'] )) {
          $setting['background_color'] = apply_filters( 'pre_term_name', $data['background_color'] );
      }
      if ( isset( $data['background_image'] )) {
          $setting['background_image'] = absint( $data['background_image'] );
      }
      if ( isset( $data['background_repeat'] )) {
          $setting['background_repeat'] = apply_filters( 'pre_term_name', $data['background_repeat'] );
      }
      if ( isset( $data['text_color'] )) {
          $setting['text_color'] = apply_filters( 'pre_term_name', $data['text_color'] );
      }
      if ( isset( $data['link_color'] )) {
          $setting['link_color'] = apply_filters( 'pre_term_name', $data['link_color'] );
      }
      if ( isset( $data['link_hover_color'] )) {
          $setting['link_hover_color'] = apply_filters( 'pre_term_name', $data['link_hover_color'] );
      }
      if ( isset( $data['padding'] )) {
          $setting['padding'] = absint( $data['padding'] );
      }
      if ( isset( $data['border_width'] )) {
          $setting['border_width'] = absint( $data['border_width'] );
      }
      if ( isset( $data['border_color'] )) {
          $setting['border_color'] = apply_filters( 'pre_term_name', $data['border_color'] );
      }
      if ( isset( $data['border_style'] )) {
          $setting['border_style'] = apply_filters( 'pre_term_name', $data['border_style'] );
      }
      if ( isset( $data['border_radius'] )) {
          $setting['border_radius'] = apply_filters( 'pre_term_name', $data['border_radius'] );
      }
      if ( isset( $data['font_family'] )) {
          $setting['font_family'] = apply_filters( 'pre_term_name', $data['font_family'] );
      }
      if ( isset( $data['shadow'] )) {
          $setting['shadow'] = apply_filters( 'pre_term_name', $data['shadow'] );
      }
      if ( isset( $data['list_style'] )) {
          $setting['list_style'] = apply_filters( 'pre_term_name', $data['list_style'] );
      }

      //
      //
      // Video
      //
      if ( isset( $data['video_show'] )) {
        $setting['video_show'] = apply_filters( 'pre_term_name', $data['video_show'] );
      }
      if ( isset( $data['video_url'] )) {
        $setting['video_url'] = apply_filters( 'pre_link_url', $data['video_url'] );
      }
      if ( isset( $data['video_start'] )) {
        $setting['video_start'] = absint( $data['video_start'] );
      }
      if ( isset( $data['video_width'] )) {
        $setting['video_width'] = absint( $data['video_width'] );
      }
      if ( isset( $data['video_height'] )) {
        $setting['video_height'] = absint( $data['video_height'] );
      }
      if ( isset( $data['video_autoplay'] )) {
          $setting['video_autoplay'] = apply_filters( 'pre_term_name', $data['video_autoplay'] );
      }

      //
      //
      // Discount Coupons
      //
      if ( isset( $data['coupon_activate'] )) {
        $setting['coupon_activate'] = apply_filters( 'pre_term_name', $data['coupon_activate'] );
      }
      if ( isset( $data['coupon_discount'] )) {
        $setting['coupon_discount'] = (float)$data['coupon_discount'];
      }
      if ( isset( $data['coupon_info'] )) {
        $setting['coupon_info'] = apply_filters( 'single_post_title', $data['coupon_info'] );
      }
      if ( isset( $data['coupon_order_label'] )) {
        $setting['coupon_order_label'] =
          apply_filters( 'single_post_title', $data['coupon_order_label'] );
      }
      if ( isset( $data['coupon_codes'] ))
      {
        $setting['coupon_codes'] = $data['coupon_codes'];
      }

      //
      //
      // Share Discount
      //
      if ( isset( $data['share_discount_activate'] )) {
        $setting['share_discount_activate'] =
          apply_filters( 'pre_term_name', $data['share_discount_activate'] );
      }
      if ( isset( $data['share_discount_value'] )) {
        $setting['share_discount_value'] = (float)$data['share_discount_value'];
      }
      if ( isset( $data['share_discount_info'] )) {
        $setting['share_discount_info'] =
          apply_filters( 'single_post_title', $data['share_discount_info'] );
      }
      if ( isset( $data['share_discount_order_label'] )) {
        $setting['share_discount_order_label'] =
          apply_filters( 'single_post_title', $data['share_discount_order_label'] );
      }
      if ( isset( $data['share_discount_button_label'] )) {
        $setting['share_discount_button_label'] =
          apply_filters( 'single_post_title', $data['share_discount_button_label'] );
      }
      if ( isset( $data['share_title'] )) {
        $setting['share_title'] = apply_filters( 'single_post_title', $data['share_title'] );
      }
      if ( isset( $data['share_url'] )) {
        $setting['share_url'] = apply_filters( 'pre_link_url', $data['share_url'] );
      }
      if ( isset( $data['share_info'] )) {
        $setting['share_info'] = apply_filters( 'single_post_title', $data['share_info'] );
      }
      if ( isset( $data['share_image'] )) {
        $setting['share_image'] = absint( $data['share_image'] );
      }

      //
      //
      // Optin Form
      //
      if ( isset( $data['autoresponder_activate'] )) {
        $setting['autoresponder_activate'] =
          apply_filters( 'pre_term_name', $data['autoresponder_activate'] );
      }
      if ( isset( $data['autoresponder_code'] )) {
        $setting['autoresponder_code'] = $data['autoresponder_code'];
      }
      if ( isset( $data['autoresponder_action'] )) {
        $setting['autoresponder_action'] =
          apply_filters( 'pre_link_url', $data['autoresponder_action'] );
      }
      if ( isset( $data['autoresponder_email'] )) {
        $setting['autoresponder_email'] =
          apply_filters( 'single_post_title', $data['autoresponder_email'] );
      }
      if ( isset( $data['autoresponder_email_label'] )) {
        $setting['autoresponder_email_label'] =
          apply_filters( 'single_post_title', $data['autoresponder_email_label'] );
      }
      if ( isset( $data['autoresponder_name'] )) {
        $setting['autoresponder_name'] = $data['autoresponder_name'];
      }
      if ( isset( $data['autoresponder_name_label'] )) {
        $setting['autoresponder_name_label'] =
          apply_filters( 'single_post_title', $data['autoresponder_name_label'] );
      }
      if ( isset( $data['autoresponder_name_activate'] )) {
        $setting['autoresponder_name_activate'] =
          apply_filters( 'pre_term_name', $data['autoresponder_name_activate'] );
      }
      if ( isset( $data['autoresponder_form_label'] )) {
        $setting['autoresponder_form_label'] =
          apply_filters( 'pre_term_name', $data['autoresponder_form_label'] );
      }
      if ( isset( $data['autoresponder_button_text'] )) {
        $setting['autoresponder_button_text'] =
          apply_filters( 'single_post_title', $data['autoresponder_button_text'] );
      }
      if ( isset( $data['autoresponder_button_style'] )) {
        $setting['autoresponder_button_style'] =
          apply_filters( 'pre_term_name', $data['autoresponder_button_style'] );
      }

      //
      //
      // Cart Button
      //
      if ( isset( $data['payment_url'] )) {
        $setting['payment_url'] = apply_filters( 'pre_link_url', $data['payment_url'] );
      }
      if ( isset( $data['payment_support'] )) {
        $setting['payment_support'] = (array) $data['payment_support'];
      }
      if ( isset( $data['buy_button_type'] )) {
        $setting['buy_button_type'] = apply_filters( 'pre_term_name', $data['buy_button_type'] );
      }
      if ( isset( $data['buy_button_label'] )) {
        $setting['buy_button_label'] = apply_filters( 'single_post_title', $data['buy_button_label'] );
      }
      if ( isset( $data['buy_button_style'] )) {
        $setting['buy_button_style'] = apply_filters( 'pre_term_name', $data['buy_button_style'] );
      }
      if ( isset( $data['buy_button_style_color'] )) {
        $setting['buy_button_style_color'] =
          apply_filters( 'pre_term_name', $data['buy_button_style_color'] );
      }
      if ( isset( $data['buy_button_size'] )) {
        $setting['buy_button_size'] = apply_filters( 'pre_term_name', $data['buy_button_size'] );
      }
      if ( isset( $data['buy_button_image'] )) {
        $setting['buy_button_image'] = apply_filters( 'pre_term_name', $data['buy_button_image'] );
      }
      if ( isset( $data['buy_button_image_size'] )) {
        $setting['buy_button_image_size'] =
          apply_filters( 'pre_term_name', $data['buy_button_image_size'] );
      }
      if ( isset( $data['buy_button_upload'] )) {
        $setting['buy_button_upload'] = absint( $data['buy_button_upload'] );
      }

      //
      //
      // List
      //
      $lists = array();
      if ( ! empty( $data['list_title'] ))
      {
        $titles = $data['list_title'];
        $prices = $data['list_price'];
        $mands  = $data['list_mandatory'];

        foreach( $titles as $key => $title )
        {
          if ( empty( $title )) {
            continue;
          }
          $data = array(
            'title' => $title
          );
          if ( ! empty( $prices[$key] )) {
            $data['price'] = $prices[$key];
          } else {
            $data['price'] = 0;
          }
          $data['mandatory'] = absint( $mands[$key] );
          $lists[] = $data;
        }
      }
      $setting['lists'] = $lists;

      return $setting;
    }
  }
}
?>
